@@ -27,10 +27,14 @@ def str_to_date(data: Union[str, date], format: str = "%Y-%m-%d") -> date:
 
 
 def datetime_to_str(data: datetime) -> str:
+    if isinstance(data, str):
+        return data
     return data.strftime("%Y-%m-%d %H:%M:%S")
 
 
 def date_to_str(data: date) -> str:
+    if isinstance(data, str):
+        return data
     return data.strftime("%Y-%m-%d")
 
 
@@ -42,4 +46,4 @@ def register_hooks():
     # attr -> dict
     cattr.register_unstructure_hook(date, date_to_str)
     cattr.register_unstructure_hook(datetime, datetime_to_str)
-    cattr.register_unstructure_hook(UUID, lambda d, t: str(d))
+    cattr.register_unstructure_hook(UUID, str)
